﻿param($installPath, $toolsPath, $package, $project)

$analyzersDir = Join-Path (Split-Path -Path $toolsPath -Parent) "analyzers"
if (-Not (Test-Path $analyzersDir))
{
    return
}

$analyzersPaths = Join-Path ( $analyzersDir ) * -Resolve

foreach($analyzersPath in $analyzersPaths)
{
    # Uninstall the language agnostic analyzers.
    if (Test-Path $analyzersPath)
    {
        foreach ($analyzerFilePath in Get-ChildItem $analyzersPath -Filter *.dll)
        {
            if($project.Object.AnalyzerReferences)
            {
                $project.Object.AnalyzerReferences.Remove($analyzerFilePath.FullName)
            }
        }
    }
}

# $project.Type gives the language name like (C# or VB.NET)
$languageFolder = ""
if($project.Type -eq "C#")
{
    $languageFolder = "cs"
}
if($project.Type -eq "VB.NET")
{
    $languageFolder = "vb"
}
if($languageFolder -eq "")
{
    return
}

foreach($analyzersPath in $analyzersPaths)
{
    # Uninstall language specific analyzers.
    $languageAnalyzersPath = join-path $analyzersPath $languageFolder
    if (Test-Path $languageAnalyzersPath)
    {
        foreach ($analyzerFilePath in Get-ChildItem $languageAnalyzersPath -Filter *.dll)
        {
            if($project.Object.AnalyzerReferences)
            {
                try
                {
                    $project.Object.AnalyzerReferences.Remove($analyzerFilePath.FullName)
                }
                catch
                {

                }
            }
        }
    }
}
# SIG # Begin signature block
# MIIpGAYJKoZIhvcNAQcCoIIpCTCCKQUCAQExDzANBglghkgBZQMEAgEFADB5Bgor
# BgEEAYI3AgEEoGswaTA0BgorBgEEAYI3AgEeMCYCAwEAAAQQH8w7YFlLCE63JNLG
# KX7zUQIBAAIBAAIBAAIBAAIBADAxMA0GCWCGSAFlAwQCAQUABCB5mT/HBF+ApGFF
# NurlQsK+/gKFs6a98ziX+/GaLDsVJqCCDeUwggZjMIIES6ADAgECAhMzAAAD03Zp
# 3IDsAaJDAAAAAAPTMA0GCSqGSIb3DQEBDAUAMH4xCzAJBgNVBAYTAlVTMRMwEQYD
# VQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNy
# b3NvZnQgQ29ycG9yYXRpb24xKDAmBgNVBAMTH01pY3Jvc29mdCBDb2RlIFNpZ25p
# bmcgUENBIDIwMTEwHhcNMjQwMjIyMjAyNTUzWhcNMjUwMjE5MjAyNTUzWjBjMQsw
# CQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9u
# ZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMQ0wCwYDVQQDEwQuTkVU
# MIIBojANBgkqhkiG9w0BAQEFAAOCAY8AMIIBigKCAYEAomvdYVuijyGO9gsZje0j
# qKf3y22pECl1v5BVS23irM6NRTqPMmVHqJYLORDpThk14BjmPm6UCoPkzHf6HPEy
# nhRQs2aroUX/yiIISqFtxglKXKylW1FvsY7xdRIq/nBVXWE2uamfM7Hifa73R5n5
# 6EUG4NxwhJqJgW2ttBkJL2FlfGh5LJXzqJWz1Bp60eiO9TK0luO16btNYm+9oMOi
# xh5FpfbAO1NoAlVJzRfg7fAgdrNxQVY/V2i7rl8H8zgvugLIQZt6qJGsMTiSzIUX
# 0JUB7jlSUhzH1v/yAWlX1issaALddCVlJgNbRkXaELU3wInNAmuKViOSA06xUlsM
# eZ+jov0gStKWERLGyeMM2Yd97FQ+2t2kdHbXLi1ei7EyUbDJKuCO+hOsHnn3UuRc
# 46Qa7sasYMoDJohgUqHA4hqWZnXdqYT/BnG/HBhklIQy6SnkieXh+PGlr3mj9ROw
# 2iswm4oN5VvabHtt3Iv2EsTlbR7XLnkmMoVCEyTMAoJNAgMBAAGjggFzMIIBbzAf
# BgNVHSUEGDAWBgorBgEEAYI3TAgBBggrBgEFBQcDAzAdBgNVHQ4EFgQUTaaU7tbi
# G+nvxDrZLFFdfEOF/AEwRQYDVR0RBD4wPKQ6MDgxHjAcBgNVBAsTFU1pY3Jvc29m
# dCBDb3Jwb3JhdGlvbjEWMBQGA1UEBRMNNDY0MjIzKzUwMjA4MjAfBgNVHSMEGDAW
# gBRIbmTlUAXTgqoXNzcitW2oynUClTBUBgNVHR8ETTBLMEmgR6BFhkNodHRwOi8v
# d3d3Lm1pY3Jvc29mdC5jb20vcGtpb3BzL2NybC9NaWNDb2RTaWdQQ0EyMDExXzIw
# MTEtMDctMDguY3JsMGEGCCsGAQUFBwEBBFUwUzBRBggrBgEFBQcwAoZFaHR0cDov
# L3d3dy5taWNyb3NvZnQuY29tL3BraW9wcy9jZXJ0cy9NaWNDb2RTaWdQQ0EyMDEx
# XzIwMTEtMDctMDguY3J0MAwGA1UdEwEB/wQCMAAwDQYJKoZIhvcNAQEMBQADggIB
# AHevsfmqNH8UxuWAqhCQ1zLEd62Xvc6XAq1SjXvLlEGYHghJyv+E23XCbnnGP4dh
# RfIFcPacIJzEmYIGkmvhYJe2oE/pg+46juUUzMVhWL5D1yTxM7GJovIk/sbcgGzI
# eIdSEihrLuuCkU7T917RNDQ1TSgJeaAxPprDqsuc65rMQpRBlbW2tTpOarALpoU4
# hEWk95jGn8rVv2PlccP3fQA6QiUdd77bRZE+99ymHq5n8uhqT0iQniGzvADisevF
# sHDO1AUBuVl8+ZDIWpAtg8/UalWZldJ0QfNMEqfzyRY1ssLjiYCGRVER2IBMbYHa
# Z5wkNlfKYUfihMnDrhwEfUNAh2SK5usjjrMT1S26TgvA7vhxBRzAf7iolsOzEGOg
# siT7J6zFmZolaCrLEdkZl75puaRtCkbNQnB3lPIfjlhvkdEMimMqNtuOyRUFj13b
# MkaiHe/WxnfE92I7mwyaZhnCOvjkhf8KJDFbOe1RjzqhwA2zRwNEpG+m+Zr9xsut
# qQ0u5d1yK5hjy5C9OkrC3CPghxVmtcAhX424Tb3tU5yAjrQkVn2Oc/AWdG+2PsQo
# 1jd2lk8/w1ScQBRMSvpfdNF3bTBSCxrJqHxoZgK3LPteaEexeoJOu2q4/YvbZ0C6
# Zy8tRrMMgEFhKhVbFYN8XwKo8tPNdZxOJWt5fPnDG18aMIIHejCCBWKgAwIBAgIK
# YQ6Q0gAAAAAAAzANBgkqhkiG9w0BAQsFADCBiDELMAkGA1UEBhMCVVMxEzARBgNV
# BAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jv
# c29mdCBDb3Jwb3JhdGlvbjEyMDAGA1UEAxMpTWljcm9zb2Z0IFJvb3QgQ2VydGlm
# aWNhdGUgQXV0aG9yaXR5IDIwMTEwHhcNMTEwNzA4MjA1OTA5WhcNMjYwNzA4MjEw
# OTA5WjB+MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UE
# BxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSgwJgYD
# VQQDEx9NaWNyb3NvZnQgQ29kZSBTaWduaW5nIFBDQSAyMDExMIICIjANBgkqhkiG
# 9w0BAQEFAAOCAg8AMIICCgKCAgEAq/D6chAcLq3YbqqCEE00uvK2WCGfQhsqa+la
# UKq4BjgaBEm6f8MMHt03a8YS2AvwOMKZBrDIOdUBFDFC04kNeWSHfpRgJGyvnkmc
# 6Whe0t+bU7IKLMOv2akrrnoJr9eWWcpgGgXpZnboMlImEi/nqwhQz7NEt13YxC4D
# dato88tt8zpcoRb0RrrgOGSsbmQ1eKagYw8t00CT+OPeBw3VXHmlSSnnDb6gE3e+
# lD3v++MrWhAfTVYoonpy4BI6t0le2O3tQ5GD2Xuye4Yb2T6xjF3oiU+EGvKhL1nk
# kDstrjNYxbc+/jLTswM9sbKvkjh+0p2ALPVOVpEhNSXDOW5kf1O6nA+tGSOEy/S6
# A4aN91/w0FK/jJSHvMAhdCVfGCi2zCcoOCWYOUo2z3yxkq4cI6epZuxhH2rhKEmd
# X4jiJV3TIUs+UsS1Vz8kA/DRelsv1SPjcF0PUUZ3s/gA4bysAoJf28AVs70b1FVL
# 5zmhD+kjSbwYuER8ReTBw3J64HLnJN+/RpnF78IcV9uDjexNSTCnq47f7Fufr/zd
# sGbiwZeBe+3W7UvnSSmnEyimp31ngOaKYnhfsi+E11ecXL93KCjx7W3DKI8sj0A3
# T8HhhUSJxAlMxdSlQy90lfdu+HggWCwTXWCVmj5PM4TasIgX3p5O9JawvEagbJjS
# 4NaIjAsCAwEAAaOCAe0wggHpMBAGCSsGAQQBgjcVAQQDAgEAMB0GA1UdDgQWBBRI
# bmTlUAXTgqoXNzcitW2oynUClTAZBgkrBgEEAYI3FAIEDB4KAFMAdQBiAEMAQTAL
# BgNVHQ8EBAMCAYYwDwYDVR0TAQH/BAUwAwEB/zAfBgNVHSMEGDAWgBRyLToCMZBD
# uRQFTuHqp8cx0SOJNDBaBgNVHR8EUzBRME+gTaBLhklodHRwOi8vY3JsLm1pY3Jv
# c29mdC5jb20vcGtpL2NybC9wcm9kdWN0cy9NaWNSb29DZXJBdXQyMDExXzIwMTFf
# MDNfMjIuY3JsMF4GCCsGAQUFBwEBBFIwUDBOBggrBgEFBQcwAoZCaHR0cDovL3d3
# dy5taWNyb3NvZnQuY29tL3BraS9jZXJ0cy9NaWNSb29DZXJBdXQyMDExXzIwMTFf
# MDNfMjIuY3J0MIGfBgNVHSAEgZcwgZQwgZEGCSsGAQQBgjcuAzCBgzA/BggrBgEF
# BQcCARYzaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3BraW9wcy9kb2NzL3ByaW1h
# cnljcHMuaHRtMEAGCCsGAQUFBwICMDQeMiAdAEwAZQBnAGEAbABfAHAAbwBsAGkA
# YwB5AF8AcwB0AGEAdABlAG0AZQBuAHQALiAdMA0GCSqGSIb3DQEBCwUAA4ICAQBn
# 8oalmOBUeRou09h0ZyKbC5YR4WOSmUKWfdJ5DJDBZV8uLD74w3LRbYP+vj/oCso7
# v0epo/Np22O/IjWll11lhJB9i0ZQVdgMknzSGksc8zxCi1LQsP1r4z4HLimb5j0b
# pdS1HXeUOeLpZMlEPXh6I/MTfaaQdION9MsmAkYqwooQu6SpBQyb7Wj6aC6VoCo/
# KmtYSWMfCWluWpiW5IP0wI/zRive/DvQvTXvbiWu5a8n7dDd8w6vmSiXmE0OPQvy
# CInWH8MyGOLwxS3OW560STkKxgrCxq2u5bLZ2xWIUUVYODJxJxp/sfQn+N4sOiBp
# mLJZiWhub6e3dMNABQamASooPoI/E01mC8CzTfXhj38cbxV9Rad25UAqZaPDXVJi
# hsMdYzaXht/a8/jyFqGaJ+HNpZfQ7l1jQeNbB5yHPgZ3BtEGsXUfFL5hYbXw3MYb
# BL7fQccOKO7eZS/sl/ahXJbYANahRr1Z85elCUtIEJmAH9AAKcWxm6U/RXceNcbS
# oqKfenoi+kiVH6v7RyOA9Z74v2u3S5fi63V4GuzqN5l5GEv/1rMjaHXmr/r8i+sL
# gOppO6/8MO0ETI7f33VtY5E90Z1WTk+/gFcioXgRMiF670EKsT/7qMykXcGhiJtX
# cVZOSEXAQsmbdlsKgEhr/Xmfwb1tbWrJUnMTDXpQzTGCGokwghqFAgEBMIGVMH4x
# CzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRt
# b25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xKDAmBgNVBAMTH01p
# Y3Jvc29mdCBDb2RlIFNpZ25pbmcgUENBIDIwMTECEzMAAAPTdmncgOwBokMAAAAA
# A9MwDQYJYIZIAWUDBAIBBQCgga4wGQYJKoZIhvcNAQkDMQwGCisGAQQBgjcCAQQw
# HAYKKwYBBAGCNwIBCzEOMAwGCisGAQQBgjcCARUwLwYJKoZIhvcNAQkEMSIEILtE
# eMEUesXcycnvAB00C1m+1XkEcUBjfhNIN2IZgfkZMEIGCisGAQQBgjcCAQwxNDAy
# oBSAEgBNAGkAYwByAG8AcwBvAGYAdKEagBhodHRwOi8vd3d3Lm1pY3Jvc29mdC5j
# b20wDQYJKoZIhvcNAQEBBQAEggGATdtr+3vKt6ZxrQqmgNjiLKCiqmgvV7M09A2M
# TdWMwwGN1R7T7WKqlH3+NmJ6v84hun8U0zDS5zdp+U67hs+Je1ccGu/9o3X/nNZk
# xrpj1ackYUbRqAgL+VWFo2Md00kBS3ObOPZUa95L9euJEr+GAMGmDjkR8XirqFsN
# zkIUKDVe85a8FtU1Wuf1Az1lzVxs8TG36fbxfPmZHkQ9IIEIBqRm/dRECiwsGkjM
# 3P94gj2Duv0MiklrXvclv8Bw4l5LCIp5I/VMSJ9aUR6wIYyVKieSyjCgtL/wkkxl
# riF3IkHudvph9E4A8WTwFCdxuoaX0f4kaMUadqW15ri8P63D96PkQPjPzCgrwrW0
# R6QpvusHlszx4qKDNRbnsi+P2LafnaoK7bBSklKtOwrUMRscgF1BH4o1FB0523zm
# NQn8IsY0+Lnh0DRDyxujaCXbchzAj7rMlxmb0/LBSjlyXlvP3HcT8w5IKKhL9hvd
# gtlclxJjYa03YLDrmK1zFn2qGiYMoYIXkzCCF48GCisGAQQBgjcDAwExghd/MIIX
# ewYJKoZIhvcNAQcCoIIXbDCCF2gCAQMxDzANBglghkgBZQMEAgEFADCCAVEGCyqG
# SIb3DQEJEAEEoIIBQASCATwwggE4AgEBBgorBgEEAYRZCgMBMDEwDQYJYIZIAWUD
# BAIBBQAEIPGQGyKdpsvaEoqJI4VylM3/HzRqRFMRhuE3HgQgQfaxAgZmGA24PlIY
# EjIwMjQwNDI1MTQ1ODA5Ljc2WjAEgAIB9KCB0aSBzjCByzELMAkGA1UEBhMCVVMx
# EzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoT
# FU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjElMCMGA1UECxMcTWljcm9zb2Z0IEFtZXJp
# Y2EgT3BlcmF0aW9uczEnMCUGA1UECxMeblNoaWVsZCBUU1MgRVNOOjM3MDMtMDVF
# MC1EOTQ3MSUwIwYDVQQDExxNaWNyb3NvZnQgVGltZS1TdGFtcCBTZXJ2aWNloIIR
# 6jCCByAwggUIoAMCAQICEzMAAAHqmiRy1Vk/YWMAAQAAAeowDQYJKoZIhvcNAQEL
# BQAwfDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcT
# B1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEmMCQGA1UE
# AxMdTWljcm9zb2Z0IFRpbWUtU3RhbXAgUENBIDIwMTAwHhcNMjMxMjA2MTg0NTMw
# WhcNMjUwMzA1MTg0NTMwWjCByzELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hp
# bmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jw
# b3JhdGlvbjElMCMGA1UECxMcTWljcm9zb2Z0IEFtZXJpY2EgT3BlcmF0aW9uczEn
# MCUGA1UECxMeblNoaWVsZCBUU1MgRVNOOjM3MDMtMDVFMC1EOTQ3MSUwIwYDVQQD
# ExxNaWNyb3NvZnQgVGltZS1TdGFtcCBTZXJ2aWNlMIICIjANBgkqhkiG9w0BAQEF
# AAOCAg8AMIICCgKCAgEAtQtf8Ug/IAfV+y7naKNq1m9pLKmheuULSZG0KZrHOhuG
# 4OTDr+lj/7ieFzibyl/3NbdHo+KFganRg+lW411+E9Cn8pU7pa8yrYMZ8WYe6tbg
# 9A8v8ORtAyQz2+qMUK8+rzFdmd8vWcY32agZw36hqJ/+FQx52YXWrNtrL0guRh8s
# LENifdDDOy+HnGPE5yyPOZF101REm9PbcS9rRzGKwfihwstPHbN+mp+yHDhn0ZoR
# 2xaD2uaJvWBqVSkvMXk+xAMFu1m1y/5aOafSkUSIwJbAQRw9U3RgbnKxgt00F0k6
# fbOw45L7zRblGtASrM+lIgi8SRkEmYXdojiUxHydX8WJNp2OkgirFflZrVeWoj82
# P7FqBWOeNvs86wD6+Hpa76/bgenIvynIv/xDhEWRFEwT1zBP4mvrfI609st7oNeT
# EglboTrDa5rmRcGkQq0RA9Ms+FfcJTExhyCVueYjTNxz1SSdfbzkr6wj/ZbBHBMF
# mSENRQsjzp5DNX7O/PNHWoQGuVJj6jJOVhCscwz1adPNV+UUOhxlVM+mXYENI3E+
# fRBvgigz0Q+psfKL8yKUv6/8BBzyreZDoWK48kB13PShyk1n16QFY9UsqreV+J6/
# jKXrm7/jfz40BD69ImCQ40sya6iC4QbOacrW+r8kfB1FTKfpgAOK14zsONr5B30C
# AwEAAaOCAUkwggFFMB0GA1UdDgQWBBQrgUUlolHm6RdAVNTEyHKLBW5ZXjAfBgNV
# HSMEGDAWgBSfpxVdAF5iXYP05dJlpxtTNRnpcjBfBgNVHR8EWDBWMFSgUqBQhk5o
# dHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20vcGtpb3BzL2NybC9NaWNyb3NvZnQlMjBU
# aW1lLVN0YW1wJTIwUENBJTIwMjAxMCgxKS5jcmwwbAYIKwYBBQUHAQEEYDBeMFwG
# CCsGAQUFBzAChlBodHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20vcGtpb3BzL2NlcnRz
# L01pY3Jvc29mdCUyMFRpbWUtU3RhbXAlMjBQQ0ElMjAyMDEwKDEpLmNydDAMBgNV
# HRMBAf8EAjAAMBYGA1UdJQEB/wQMMAoGCCsGAQUFBwMIMA4GA1UdDwEB/wQEAwIH
# gDANBgkqhkiG9w0BAQsFAAOCAgEAKIOtVl4/fv58VW19xt+yoL8qDQJ7rtsNx6Fm
# Y9x9GAnkN2/SkmU4VU4VuIhXB6yp4RTAW1yV+LkCOd5Dlkmlgmld8Qs56Ubd3OP4
# Ep93bzv9Rj9zCZKSX4KOegoEvcyzoj99ZH5qVHT6npGW+IrzEei6D2+RzZatFmwa
# cxW7bE4za08n6qnKgMHOq/fQ39lEE6g2tL88KQPAsYgINipWz8jMATj3K/YSU/LB
# qV/2YSw4ddXWXG1AM1x6NUSaK0kn7VWvYS1p88RsxBmnz1MC5qBE4oThi6iEJQqb
# 6/eB4mpNBqtMGOpXblEI5P5cWeBMwMP3BjHpPCd0HYjUvLvbo2IdQezS6+rdyIJX
# 0nA1d23VVnrdYrU1KClUSyIr0Q8AE+3UR9dwqt9o9iRuQWLv14rURPHHc2iZg1Qc
# 2IZT5fUF7wvuqkfCOjSDf/fdeG06v0uIOhReH9XYsVMROKpX1DzIsRq9BbeP0tD+
# H8JobPlh0Z+tjweI98wh4sSiQrEZ/SEdxMQUCkHTIuWroqgesUAQA1H/he4UimX2
# wPLBUha3i0qob4/qlEBfODXMbmsaWyVlabDtfCC+EG7eOQs/0DGuxJjBjZ+2vDDN
# 7k0DpUMtLunP46tddYtSajI2sk3HkGTTATDORDHOQ6+Zt0+Gw4/VkzS4D/EhXtxK
# k2llTDkwggdxMIIFWaADAgECAhMzAAAAFcXna54Cm0mZAAAAAAAVMA0GCSqGSIb3
# DQEBCwUAMIGIMQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4G
# A1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMTIw
# MAYDVQQDEylNaWNyb3NvZnQgUm9vdCBDZXJ0aWZpY2F0ZSBBdXRob3JpdHkgMjAx
# MDAeFw0yMTA5MzAxODIyMjVaFw0zMDA5MzAxODMyMjVaMHwxCzAJBgNVBAYTAlVT
# MRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQK
# ExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xJjAkBgNVBAMTHU1pY3Jvc29mdCBUaW1l
# LVN0YW1wIFBDQSAyMDEwMIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEA
# 5OGmTOe0ciELeaLL1yR5vQ7VgtP97pwHB9KpbE51yMo1V/YBf2xK4OK9uT4XYDP/
# XE/HZveVU3Fa4n5KWv64NmeFRiMMtY0Tz3cywBAY6GB9alKDRLemjkZrBxTzxXb1
# hlDcwUTIcVxRMTegCjhuje3XD9gmU3w5YQJ6xKr9cmmvHaus9ja+NSZk2pg7uhp7
# M62AW36MEBydUv626GIl3GoPz130/o5Tz9bshVZN7928jaTjkY+yOSxRnOlwaQ3K
# Ni1wjjHINSi947SHJMPgyY9+tVSP3PoFVZhtaDuaRr3tpK56KTesy+uDRedGbsoy
# 1cCGMFxPLOJiss254o2I5JasAUq7vnGpF1tnYN74kpEeHT39IM9zfUGaRnXNxF80
# 3RKJ1v2lIH1+/NmeRd+2ci/bfV+AutuqfjbsNkz2K26oElHovwUDo9Fzpk03dJQc
# NIIP8BDyt0cY7afomXw/TNuvXsLz1dhzPUNOwTM5TI4CvEJoLhDqhFFG4tG9ahha
# YQFzymeiXtcodgLiMxhy16cg8ML6EgrXY28MyTZki1ugpoMhXV8wdJGUlNi5UPkL
# iWHzNgY1GIRH29wb0f2y1BzFa/ZcUlFdEtsluq9QBXpsxREdcu+N+VLEhReTwDwV
# 2xo3xwgVGD94q0W29R6HXtqPnhZyacaue7e3PmriLq0CAwEAAaOCAd0wggHZMBIG
# CSsGAQQBgjcVAQQFAgMBAAEwIwYJKwYBBAGCNxUCBBYEFCqnUv5kxJq+gpE8RjUp
# zxD/LwTuMB0GA1UdDgQWBBSfpxVdAF5iXYP05dJlpxtTNRnpcjBcBgNVHSAEVTBT
# MFEGDCsGAQQBgjdMg30BATBBMD8GCCsGAQUFBwIBFjNodHRwOi8vd3d3Lm1pY3Jv
# c29mdC5jb20vcGtpb3BzL0RvY3MvUmVwb3NpdG9yeS5odG0wEwYDVR0lBAwwCgYI
# KwYBBQUHAwgwGQYJKwYBBAGCNxQCBAweCgBTAHUAYgBDAEEwCwYDVR0PBAQDAgGG
# MA8GA1UdEwEB/wQFMAMBAf8wHwYDVR0jBBgwFoAU1fZWy4/oolxiaNE9lJBb186a
# GMQwVgYDVR0fBE8wTTBLoEmgR4ZFaHR0cDovL2NybC5taWNyb3NvZnQuY29tL3Br
# aS9jcmwvcHJvZHVjdHMvTWljUm9vQ2VyQXV0XzIwMTAtMDYtMjMuY3JsMFoGCCsG
# AQUFBwEBBE4wTDBKBggrBgEFBQcwAoY+aHR0cDovL3d3dy5taWNyb3NvZnQuY29t
# L3BraS9jZXJ0cy9NaWNSb29DZXJBdXRfMjAxMC0wNi0yMy5jcnQwDQYJKoZIhvcN
# AQELBQADggIBAJ1VffwqreEsH2cBMSRb4Z5yS/ypb+pcFLY+TkdkeLEGk5c9MTO1
# OdfCcTY/2mRsfNB1OW27DzHkwo/7bNGhlBgi7ulmZzpTTd2YurYeeNg2LpypglYA
# A7AFvonoaeC6Ce5732pvvinLbtg/SHUB2RjebYIM9W0jVOR4U3UkV7ndn/OOPcbz
# aN9l9qRWqveVtihVJ9AkvUCgvxm2EhIRXT0n4ECWOKz3+SmJw7wXsFSFQrP8DJ6L
# GYnn8AtqgcKBGUIZUnWKNsIdw2FzLixre24/LAl4FOmRsqlb30mjdAy87JGA0j3m
# Sj5mO0+7hvoyGtmW9I/2kQH2zsZ0/fZMcm8Qq3UwxTSwethQ/gpY3UA8x1RtnWN0
# SCyxTkctwRQEcb9k+SS+c23Kjgm9swFXSVRk2XPXfx5bRAGOWhmRaw2fpCjcZxko
# JLo4S5pu+yFUa2pFEUep8beuyOiJXk+d0tBMdrVXVAmxaQFEfnyhYWxz/gq77EFm
# PWn9y8FBSX5+k77L+DvktxW/tM4+pTFRhLy/AsGConsXHRWJjXD+57XQKBqJC482
# 2rpM+Zv/Cuk0+CQ1ZyvgDbjmjJnW4SLq8CdCPSWU5nR0W2rRnj7tfqAxM328y+l7
# vzhwRNGQ8cirOoo6CGJ/2XBjU02N7oJtpQUQwXEGahC0HVUzWLOhcGbyoYIDTTCC
# AjUCAQEwgfmhgdGkgc4wgcsxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5n
# dG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9y
# YXRpb24xJTAjBgNVBAsTHE1pY3Jvc29mdCBBbWVyaWNhIE9wZXJhdGlvbnMxJzAl
# BgNVBAsTHm5TaGllbGQgVFNTIEVTTjozNzAzLTA1RTAtRDk0NzElMCMGA1UEAxMc
# TWljcm9zb2Z0IFRpbWUtU3RhbXAgU2VydmljZaIjCgEBMAcGBSsOAwIaAxUAidse
# 3EH46UbJCfFBiHLTgpJhJI+ggYMwgYCkfjB8MQswCQYDVQQGEwJVUzETMBEGA1UE
# CBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9z
# b2Z0IENvcnBvcmF0aW9uMSYwJAYDVQQDEx1NaWNyb3NvZnQgVGltZS1TdGFtcCBQ
# Q0EgMjAxMDANBgkqhkiG9w0BAQsFAAIFAOnUV9QwIhgPMjAyNDA0MjUwNDE3MjRa
# GA8yMDI0MDQyNjA0MTcyNFowdDA6BgorBgEEAYRZCgQBMSwwKjAKAgUA6dRX1AIB
# ADAHAgEAAgJPRzAHAgEAAgITyzAKAgUA6dWpVAIBADA2BgorBgEEAYRZCgQCMSgw
# JjAMBgorBgEEAYRZCgMCoAowCAIBAAIDB6EgoQowCAIBAAIDAYagMA0GCSqGSIb3
# DQEBCwUAA4IBAQB8pRXqzpAO0EWz5Zp3CizQlsQ39C1ijGkUnwSPrSI/6sUcyKHO
# fUSmHuuEyQR/j8q1JAVSGcWDqHwpFr4NqZ4/JwMi3kbK3EIuGPECJQLmbfSg0VC8
# sPqk5OZ3eYfWdzcAO373lzF3YTYz9S33Pb+baeWdyLwTRezM6A5xGYMRRmgiorhq
# hmjLRMoaUTdGT/SPgOvfBsCyCac0s9LUqshJlBNlNe3d8uX4nk1GdgLqDGna+ZgH
# lxfgLJocm88o4PcAPv+gY+IMR+VNFkllGnwb80goKF9nrw3zf881JSEOQ9aojdl6
# YNNGayCT/+dfVaGRusmvBeUItP1cyKbFtyM9MYIEDTCCBAkCAQEwgZMwfDELMAkG
# A1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQx
# HjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEmMCQGA1UEAxMdTWljcm9z
# b2Z0IFRpbWUtU3RhbXAgUENBIDIwMTACEzMAAAHqmiRy1Vk/YWMAAQAAAeowDQYJ
# YIZIAWUDBAIBBQCgggFKMBoGCSqGSIb3DQEJAzENBgsqhkiG9w0BCRABBDAvBgkq
# hkiG9w0BCQQxIgQgYaIUzT+Aoc+9M5LLCWj2Ij3UR79MC+tgjf6ziWU0+NgwgfoG
# CyqGSIb3DQEJEAIvMYHqMIHnMIHkMIG9BCApj6HV42Q0eIsINJbSwDVwYeRtbiqi
# iL6vLIynpLhmeDCBmDCBgKR+MHwxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNo
# aW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29y
# cG9yYXRpb24xJjAkBgNVBAMTHU1pY3Jvc29mdCBUaW1lLVN0YW1wIFBDQSAyMDEw
# AhMzAAAB6pokctVZP2FjAAEAAAHqMCIEIDt7cFOkXbAjR01DkVx0LIvPK06+/5M/
# 6QgB7TGHGtidMA0GCSqGSIb3DQEBCwUABIICAFTLDnfNZVgmBRv2vOzBpBKjuGLb
# xPkZDdTKXAJP8oaMBGutD0PcA4Xwx/N2W/E5rBm8iCmfMHQTBXLnNLAmBES5ttPr
# Cg5Baz0E6MSc6gzzcl6wZWgftZngSM0gefyHzeKBX38bg2TOsXbRRcP3u0PnKsAi
# CrJec/qZ/pRBNwNXc+Ylx8QaF9zYmncKR2QhcUdKcZQy2TUIzec+KI3AcjJZD8IN
# e9WE0PsxztRyKeflxzuk1E/nyrRf60Tomk5Q/VmP0BV/a41NpZhJeM9gFY13LGt5
# Bq5jL/8R27LwWYrrcWbmtosgqOZALtcmr43ao2jC56DQiPMd2wyo7PQv1/x8DdpL
# 5rGzQO1ztfVS+clA9ogn+qEaHTOeclUZGn3q3bzqjxC0hqGLFWa+z+k5WLJS36Lq
# M+KIsPtQ/oOb5KRhtVsF+9DujCOqEAj6hsrw+uy0YL90pMMeQtJvVxuW7YPk54cV
# N7hQyxYCA+ftV7sfv5qP5zCvsDu3YTEXpiYf5Rwez7FGFABcKVcGX4ptrZ49PWpa
# cT0WRLcwb14ML8M30rf4KuWy5iceUnGXYKNqMBsaeMhUXyBA1U8MMvylaNdYKiyV
# 60vVoCqAEzN4VaQV2AQsEbA2ENqgY340BxECqKdS4MWXH5BvnD1IqPjgu/pFlD4O
# 1k53r5meA94doBQN
# SIG # End signature block
